==> gridjs-6.0.2.tgz: package/README.md <==
# Grid.js
<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-5-orange.svg?style=flat-square)](#contributors-)
<!-- ALL-CONTRIBUTORS-BADGE:END -->

<p align="center">
    <a href="https://gridjs.io" target="_blank">
        <img src="https://gridjs.io/img/logo/text_large.png" height="200" alt="Grid.js" />
    </a>
</p>
<p align="center">Advanced table plugin</p>

**A table library that works everywhere**

- Simple and lightweight implementation
- No vendor lock-in. Grid.js can be used with any JavaScript frameworks (React, Angular, Preact or VanillaJS)
- Written in TypeScript 
- Supports all modern browsers and IE11+

## Example

```js
new Grid({
  data: [
    ['Mike', 33, 'mike@murphy.com'],
    ['John', 82, 'john@conway.com'],
    ['Sara', 26, 'sara@keegan.com']
  ],
  columns: ['Name', 'Age', 'Email']
}).render(document.getElementById('wrapper'));
```

Piece of :cake:

## Getting Started

- [Install](https://gridjs.io/docs/install)
- [Getting Started](https://gridjs.io/docs/index)
- [Examples](https://gridjs.io/docs/examples/hello-world)

## Documentation :book:

Full documentation of Grid.js installation, config, API and examples are available
on Grid.js website [grid.js/docs](https://gridjs.io/docs/index). 

## Community

- Join our [Discord channel](https://discord.gg/K55BwDY)
- Take a look at [gridjs](https://stackoverflow.com/questions/tagged/gridjs) tag on StackOverflow or ask your own question!
- Read our [blog](https://gridjs.io/blog) for the latest updates and announcements
- Follow our Twitter account [@grid_js](https://twitter.com/grid_js)

## Contributors ✨

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a href="http://afshinm.name"><img src="https://avatars3.githubusercontent.com/u/314326?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Afshin Mehrabani</b></sub></a><br /><a href="https://github.com/grid-js/gridjs/commits?author=afshinm" title="Code">💻</a> <a href="https://github.com/grid-js/gridjs/commits?author=afshinm" title="Documentation">📖</a></td>
    <td align="center"><a href="https://self.agency"><img src="https://avatars.githubusercontent.com/u/2541728?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Daniel Sieradski</b></sub></a><br /><a href="#plugin-selfagency" title="Plugin/utility libraries">🔌</a></td>
    <td align="center"><a href="http://salamaashoush.com"><img src="https://avatars.githubusercontent.com/u/13505298?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Salama Ashoush</b></sub></a><br /><a href="#plugin-salamaashoush" title="Plugin/utility libraries">🔌</a></td>
    <td align="center"><a href="https://www.danielwerner.dev/"><img src="https://avatars.githubusercontent.com/u/38726367?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Daniel Werner</b></sub></a><br /><a href="#plugin-daniel-werner" title="Plugin/utility libraries">🔌</a></td>
    <td align="center"><a href="https://aloys.dev"><img src="https://avatars.githubusercontent.com/u/17796338?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Aloysb</b></sub></a><br /><a href="https://github.com/grid-js/gridjs/commits?author=Aloysb" title="Code">💻</a> <a href="https://github.com/grid-js/gridjs/commits?author=Aloysb" title="Documentation">📖</a></td>
  </tr>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

## License

[MIT](https://github.com/grid-js/gridjs/blob/master/LICENSE)

==> gridjs-6.2.0.tgz: package/README.md <==
# Grid.js
<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-5-orange.svg?style=flat-square)](#contributors-)
<!-- ALL-CONTRIBUTORS-BADGE:END -->

<p align="center">
    <a href="https://gridjs.io" target="_blank">
        <img src="https://gridjs.io/img/logo/text_large.png" height="200" alt="Grid.js" />
    </a>
</p>
<p align="center">Advanced table plugin</p>

**A table library that works everywhere**

- Simple and lightweight implementation
- No vendor lock-in. Grid.js can be used with any JavaScript frameworks (React, Angular, Preact or VanillaJS)
- Written in TypeScript 
- Supports all modern browsers and IE11+

## Example

```js
new Grid({
  data: [
    ['Mike', 33, 'mike@murphy.com'],
    ['John', 82, 'john@conway.com'],
    ['Sara', 26, 'sara@keegan.com']
  ],
  columns: ['Name', 'Age', 'Email']
}).render(document.getElementById('wrapper'));
```

Piece of :cake:

## Getting Started

- [Install](https://gridjs.io/docs/install)
- [Getting Started](https://gridjs.io/docs/)
- [Examples](https://gridjs.io/docs/examples/hello-world)

## Documentation :book:

Full documentation of Grid.js installation, config, API and examples are available
on Grid.js website [grid.js/docs](https://gridjs.io/docs/index). 

## Community

- Join our [Discord channel](https://discord.gg/K55BwDY)
- Take a look at [gridjs](https://stackoverflow.com/questions/tagged/gridjs) tag on StackOverflow or ask your own question!
- Read our [blog](https://gridjs.io/blog) for the latest updates and announcements
- Follow our Twitter account [@grid_js](https://twitter.com/grid_js)

## Contributors ✨

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a href="http://afshinm.name"><img src="https://avatars3.githubusercontent.com/u/314326?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Afshin Mehrabani</b></sub></a><br /><a href="https://github.com/grid-js/gridjs/commits?author=afshinm" title="Code">💻</a> <a href="https://github.com/grid-js/gridjs/commits?author=afshinm" title="Documentation">📖</a></td>
    <td align="center"><a href="https://self.agency"><img src="https://avatars.githubusercontent.com/u/2541728?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Daniel Sieradski</b></sub></a><br /><a href="#plugin-selfagency" title="Plugin/utility libraries">🔌</a></td>
    <td align="center"><a href="http://salamaashoush.com"><img src="https://avatars.githubusercontent.com/u/13505298?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Salama Ashoush</b></sub></a><br /><a href="#plugin-salamaashoush" title="Plugin/utility libraries">🔌</a></td>
    <td align="center"><a href="https://www.danielwerner.dev/"><img src="https://avatars.githubusercontent.com/u/38726367?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Daniel Werner</b></sub></a><br /><a href="#plugin-daniel-werner" title="Plugin/utility libraries">🔌</a></td>
    <td align="center"><a href="https://aloys.dev"><img src="https://avatars.githubusercontent.com/u/17796338?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Aloysb</b></sub></a><br /><a href="https://github.com/grid-js/gridjs/commits?author=Aloysb" title="Code">💻</a> <a href="https://github.com/grid-js/gridjs/commits?author=Aloysb" title="Documentation">📖</a></td>
  </tr>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

## License

[MIT](https://github.com/grid-js/gridjs/blob/master/LICENSE)
